==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/ALLTEXTSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ALLTEXTSID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ALLTEXTSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ALLTEXTCODE" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *         &lt;element name="ALLTEXTLANG" type="{http://schemas.datastream.net/MP_fields}LANGUAGEID_Type"/>
 *         &lt;element name="ALLTEXTTYPE" type="{http://schemas.datastream.net/MP_fields}CODE4_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALLTEXTSID_Type", propOrder = {
    "alltextcode",
    "alltextlang",
    "alltexttype"
})
public class ALLTEXTSID_Type {

    @XmlElement(name = "ALLTEXTCODE", required = true)
    protected String alltextcode;
    @XmlElement(name = "ALLTEXTLANG", required = true)
    protected LANGUAGEID_Type alltextlang;
    @XmlElement(name = "ALLTEXTTYPE", required = true)
    protected String alltexttype;

    /**
     * Obtient la valeur de la propriété alltextcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLTEXTCODE() {
        return alltextcode;
    }

    /**
     * Définit la valeur de la propriété alltextcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLTEXTCODE(String value) {
        this.alltextcode = value;
    }

    /**
     * Obtient la valeur de la propriété alltextlang.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getALLTEXTLANG() {
        return alltextlang;
    }

    /**
     * Définit la valeur de la propriété alltextlang.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setALLTEXTLANG(LANGUAGEID_Type value) {
        this.alltextlang = value;
    }

    /**
     * Obtient la valeur de la propriété alltexttype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLTEXTTYPE() {
        return alltexttype;
    }

    /**
     * Définit la valeur de la propriété alltexttype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLTEXTTYPE(String value) {
        this.alltexttype = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/ALLTEXTSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ALLTEXTSID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ALLTEXTSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ALLTEXTCODE" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *         &lt;element name="ALLTEXTLANG" type="{http://schemas.datastream.net/MP_fields}LANGUAGEID_Type"/>
 *         &lt;element name="ALLTEXTTYPE" type="{http://schemas.datastream.net/MP_fields}CODE4_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALLTEXTSID_Type", propOrder = {
    "alltextcode",
    "alltextlang",
    "alltexttype"
})
public class ALLTEXTSID_Type {

    @XmlElement(name = "ALLTEXTCODE", required = true)
    protected String alltextcode;
    @XmlElement(name = "ALLTEXTLANG", required = true)
    protected LANGUAGEID_Type alltextlang;
    @XmlElement(name = "ALLTEXTTYPE", required = true)
    protected String alltexttype;

    /**
     * Gets the value of the alltextcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLTEXTCODE() {
        return alltextcode;
    }

    /**
     * Sets the value of the alltextcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLTEXTCODE(String value) {
        this.alltextcode = value;
    }

    /**
     * Gets the value of the alltextlang property.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getALLTEXTLANG() {
        return alltextlang;
    }

    /**
     * Sets the value of the alltextlang property.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setALLTEXTLANG(LANGUAGEID_Type value) {
        this.alltextlang = value;
    }

    /**
     * Gets the value of the alltexttype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLTEXTTYPE() {
        return alltexttype;
    }

    /**
     * Sets the value of the alltexttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLTEXTTYPE(String value) {
        this.alltexttype = value;
    }

}
